<?php

namespace Drupal\drd_eca\EventSubscriber;

use Drupal\drd\Event\DrdBase;
use Drupal\drd_eca\Plugin\ECA\Event\DrdEvent;
use Drupal\eca\EcaEvents;
use Drupal\eca\Event\BeforeInitialExecutionEvent;
use Drupal\eca\EventSubscriber\EcaBase;
use Drupal\eca\Plugin\DataType\DataTransferObject;

/**
 * ECA event subscriber.
 */
class EcaDrd extends EcaBase {

  /**
   * Subscriber method before initial execution.
   *
   * Adds the event data to the token service.
   *
   * @param \Drupal\eca\Event\BeforeInitialExecutionEvent $before_event
   *   The according event.
   *
   * @throws \Drupal\Core\TypedData\Exception\MissingDataException
   */
  public function onBeforeInitialExecution(BeforeInitialExecutionEvent $before_event): void {
    $event = $before_event->getEvent();
    if ($event instanceof DrdBase) {
      $action = $event->getAction();
      $dto = DataTransferObject::create();
      $dto->set('action', $action->getPluginId());
      $this->tokenService->addTokenData('drd', $dto);

      $entity = $event->getEntity();
      if ($entity !== NULL) {
        $this->tokenService->addTokenData('entity', $entity);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    foreach (DrdEvent::definitions() as $definition) {
      $events[$definition['event_name']][] = ['onEvent'];
    }
    $events[EcaEvents::BEFORE_INITIAL_EXECUTION][] = [
      'onBeforeInitialExecution',
      -100,
    ];
    return $events;
  }

}
