<?php

namespace Drupal\drd_migrate\Commands;

use Drupal\drd_migrate\Import;
use Drush\Commands\DrushCommands;

/**
 * Provides Drush commands for the DRD migrate module.
 *
 * @package Drupal\drd
 */
class Drush extends DrushCommands {

  /**
   * The import service.
   *
   * @var \Drupal\drd_migrate\Import
   */
  protected Import $service;

  /**
   * Drush constructor.
   *
   * @param \Drupal\drd_migrate\Import $service
   *   The import service.
   */
  public function __construct(Import $service) {
    parent::__construct();
    $this->service = $service;
  }

  /**
   * Configure this domain for communication with a DRD instance.
   *
   * @param string $inventory
   *   Filename containing the json with you DRD 7 inventory.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   *
   * @command drd:migratefromd7
   * @aliases drd-migrate-from-d7
   */
  public function migrate(string $inventory): void {
    $this->service->execute($inventory);
  }

}
